@@ -162,7 +162,7 @@ static TerminalEncoding encodings[] = {
   { TERMINAL_ENCODING_MAC_DEVANAGARI, FALSE,
     "MAC_DEVANAGARI", N_("Hindi") },
   { TERMINAL_ENCODING_MAC_FARSI, FALSE,
-    "MAC_FARSI", N_("Farsi") },
+    "MAC_FARSI", N_("Persian") },
   { TERMINAL_ENCODING_MAC_GREEK, FALSE,
     "MAC_GREEK", N_("Greek") },
   { TERMINAL_ENCODING_MAC_GUJARATI, FALSE,
@@ -352,8 +352,8 @@ update_active_encodings_from_string_list (GSList *strings)
   for (tmp = strings; tmp != NULL; tmp = tmp->next)
     {
       const TerminalEncoding *e;
-      charset = tmp->data;
       TerminalEncoding *encoding;
+      charset = tmp->data;
       
       if (strcmp (charset, "current") == 0)
         g_get_charset (&charset);
