@@ -180,7 +180,7 @@ terminal_screen_init (TerminalScreen *screen)
                              "(((news|telnet|nttp|file|http|ftp|https)://)|(www|ftp)[-A-Za-z0-9]*\\.)[-A-Za-z0-9\\.]+(:[0-9]*)?");
   
   terminal_widget_match_add (screen->priv->term,
-                             "(((news|telnet|nttp|file|http|ftp|https)://)|(www|ftp)[-A-Za-z0-9]*\\.)[-A-Za-z0-9\\.]+(:[0-9]*)?/[-A-Za-z0-9_\\$\\.\\+\\!\\*\\(\\),;:@&=\\?/~\\#\\%]*[^]'\\.}>\\) ,\\\"]");
+                             "(((news|telnet|nttp|file|http|ftp|https)://)|(www|ftp)[-A-Za-z0-9]*\\.)[-A-Za-z0-9\\.]+(:[0-9]*)?/[-A-Za-z0-9_\\$\\.\\+\\!\\*\\(\\),;:@&=\\?/~\\#\\%]*[^]'\\.}>\\) \t\r\n,\\\"]");
 
   terminal_screen_setup_dnd (screen);
   
@@ -933,7 +933,7 @@ get_child_environment (GtkWidget      *term,
           (strncmp (*p, "TERM=", 5) == 0)    ||
           (strncmp (*p, "GNOME_DESKTOP_ICON=", 19) == 0) ||
           (strncmp (*p, "COLORTERM=", 10) == 0) ||
-	  (strncmp (*p, "DISPLAY=", 8) == 0))
+	  (strncmp ( *p, "DISPLAY=", 8) == 0))
         {
           /* nothing: do not copy */
         }
@@ -952,7 +952,7 @@ get_child_environment (GtkWidget      *term,
                                GDK_WINDOW_XWINDOW (term->window));
   ++i;
   retval[i] = g_strdup_printf ("DISPLAY=%s", 
-				gdk_display_get_name(gtk_widget_get_display(term)));
+			       gdk_display_get_name(gtk_widget_get_display(term)));
   ++i;
   
   retval[i] = NULL;
@@ -1226,8 +1226,34 @@ append_stock_menuitem (GtkWidget  *menu,
                        gpointer    data)
 {
   GtkWidget *menu_item;
+  GtkWidget *image;
+  GConfClient *client;
+  GError *error;
+  gboolean use_image;
+
   
   menu_item = gtk_image_menu_item_new_from_stock (text, NULL);
+  image = gtk_image_menu_item_get_image (GTK_IMAGE_MENU_ITEM (menu_item));
+
+  client = gconf_client_get_default ();
+  error = NULL;
+
+  use_image = gconf_client_get_bool (client,
+                                     "/desktop/gnome/interface/menus_have_icons",
+                                      &error);
+  if (error)
+    {
+      g_printerr (_("There was an error loading config value for whether to use image in menus. (%s)\n"),error->message);
+      g_error_free (error);
+    }
+  else
+    {
+      if (use_image)
+        gtk_widget_show (image);
+      else
+        gtk_widget_hide (image);
+    }
+
   gtk_widget_show (menu_item);
   gtk_menu_shell_append (GTK_MENU_SHELL (menu),
                          menu_item);
@@ -1264,6 +1290,24 @@ terminal_screen_do_popup (TerminalScreen *screen,
                              GTK_WIDGET (screen->priv->term),
                              popup_menu_detach);
 
+  if (screen->priv->matched_string != NULL) 
+    {
+      menu_item = append_menuitem (screen->priv->popup_menu,
+                                   _("_Open Link"),
+                                   G_CALLBACK (open_url_callback),
+                                   screen);
+      
+      menu_item = append_menuitem (screen->priv->popup_menu,
+                                   _("_Copy Link Address"),
+                                   G_CALLBACK (copy_url_callback),
+                                   screen);
+  
+      menu_item = gtk_separator_menu_item_new ();
+      gtk_widget_show (menu_item);
+      gtk_menu_shell_append (GTK_MENU_SHELL (screen->priv->popup_menu),
+                             menu_item);
+    }
+ 
   menu_item = append_menuitem (screen->priv->popup_menu,
                                _("_New Window"),
                                G_CALLBACK (new_window_callback),
@@ -1386,21 +1430,7 @@ terminal_screen_do_popup (TerminalScreen *screen,
                    G_CALLBACK (secure_keyboard_callback),
                    screen);
 #endif
-
-  menu_item = append_menuitem (screen->priv->popup_menu,
-                               _("_Open Link"),
-                               G_CALLBACK (open_url_callback),
-                               screen);
-
-  gtk_widget_set_sensitive (menu_item, screen->priv->matched_string != NULL);
-  
-  menu_item = append_menuitem (screen->priv->popup_menu,
-                               _("_Copy Link Address"),
-                               G_CALLBACK (copy_url_callback),
-                               screen);
-
-  gtk_widget_set_sensitive (menu_item, screen->priv->matched_string != NULL);
-  
+ 
   gtk_menu_popup (GTK_MENU (screen->priv->popup_menu),
                   NULL, NULL,
                   NULL, NULL, 
