@@ -397,6 +397,28 @@ fill_in_config_picker_submenu (TerminalWindow *window)
   g_list_free (profiles);  
 }
 
+static char *
+escape_underscores (const char *name)
+{
+  GString *escaped_name;
+
+  g_assert (name != NULL);
+
+  /* Who'd use more that 4 underscores in a profile name... */
+  escaped_name = g_string_sized_new (strlen (name) + 4 + 1);
+
+  while (*name)
+    {
+      if (*name == '_')
+        g_string_append (escaped_name, "__");
+      else
+        g_string_append_c (escaped_name, *name);
+      name++;
+    }
+
+  return g_string_free (escaped_name, FALSE);
+}
+
 static void
 fill_in_new_term_submenus (TerminalWindow *window)
 {
@@ -508,6 +530,7 @@ fill_in_new_term_submenus (TerminalWindow *window)
   while (tmp != NULL)
     {
       TerminalProfile *profile;
+      char *escaped_name;
       
       profile = tmp->data;
       
@@ -515,16 +538,16 @@ fill_in_new_term_submenus (TerminalWindow *window)
       g_object_ref (G_OBJECT (profile));
       g_object_ref (G_OBJECT (profile));
 
-      /* FIXME underscores in profile name result in badness */
+      escaped_name = escape_underscores (terminal_profile_get_visible_name (profile));
+
       if (i < 10)
-        str = g_strdup_printf (_("_%d. %s"),
-                               i, terminal_profile_get_visible_name (profile));
+        str = g_strdup_printf (_("_%d. %s"), i, escaped_name);
       else if (i < 36)
-        str = g_strdup_printf (_("_%c. %s"),
-                               ('A' + i - 10),
-                               terminal_profile_get_visible_name (profile));
+        str = g_strdup_printf (_("_%c. %s"), ('A' + i - 10), escaped_name);
       else
-        str = g_strdup (terminal_profile_get_visible_name (profile));
+        str = g_strdup (escaped_name);
+
+      g_free (escaped_name);
       
       /* item for new window */
       menu_item = gtk_menu_item_new_with_mnemonic (str);
@@ -563,27 +586,6 @@ fill_in_new_term_submenus (TerminalWindow *window)
   g_list_free (profiles);
 }
 
-static void
-update_active_encoding_name (TerminalWindow *window)
-{
-  GtkWidget *w;
-  const char *charset;
-  char *name;
-  
-  w = terminal_screen_get_widget (window->priv->active_term);
-  charset = terminal_widget_get_encoding (w);
-
-  name = terminal_encoding_get_name (charset);
-
-#if 0
-  /* doesn't make sense anymore */
-  gtk_label_set_text (GTK_LABEL (gtk_bin_get_child (GTK_BIN (window->priv->encoding_menuitem))),
-                      name);
-#endif
-  
-  g_free (name);
-}
-
 static void
 fill_in_encoding_menu (TerminalWindow *window)
 {
@@ -614,8 +616,6 @@ fill_in_encoding_menu (TerminalWindow *window)
 
   w = terminal_screen_get_widget (window->priv->active_term);
   charset = terminal_widget_get_encoding (w);
-
-  update_active_encoding_name (window);
   
   group = NULL;
   encodings = terminal_get_active_encodings ();
@@ -811,7 +811,7 @@ terminal_window_init (TerminalWindow *window)
     append_menuitem (menu, _("C_urrent Profile..."), NULL,
                      G_CALLBACK (edit_configuration_callback), window);
 
-  append_menuitem (menu, _("_Keybindings..."), NULL,
+  append_menuitem (menu, _("_Keyboard Shortcuts..."), NULL,
                    G_CALLBACK (edit_keybindings_callback), window);
 
   append_menuitem (menu, _("P_rofiles..."), NULL,
@@ -1250,13 +1250,6 @@ selection_changed_callback (TerminalScreen *screen,
   update_copy_sensitivity (window);
 }
 
-static void
-encoding_changed_callback (TerminalScreen *screen,
-			  TerminalWindow *window)
-{
-  update_active_encoding_name (window);
-}
-
 void
 terminal_window_add_screen (TerminalWindow *window,
                             TerminalScreen *screen)
@@ -1310,11 +1303,6 @@ terminal_window_add_screen (TerminalWindow *window,
                     G_CALLBACK (selection_changed_callback),
                     window);
   
-  g_signal_connect (G_OBJECT (screen),
-                    "encoding_changed",
-                    G_CALLBACK (encoding_changed_callback),
-                    window);
-  
   term = terminal_screen_get_widget (screen);
 
   gtk_box_pack_start (GTK_BOX (hbox),
@@ -1745,6 +1733,8 @@ notebook_page_switched_callback (GtkWidget       *notebook,
 
   g_assert (screen);
 
+  terminal_window_set_active (window, screen);
+
   /* This is so we maintain the same grid moving among tabs with
    * different fonts.
    */
@@ -2033,6 +2023,7 @@ reset_tab_menuitems (TerminalWindow *window)
   int i;
   TerminalScreen *screen;
   GSList *group;
+  gboolean single_page;
   
   tmp = window->priv->tab_menuitems;
   while (tmp != NULL)
@@ -2044,6 +2035,8 @@ reset_tab_menuitems (TerminalWindow *window)
   g_list_free (window->priv->tab_menuitems);
   window->priv->tab_menuitems = NULL;
 
+  single_page = gtk_notebook_get_n_pages (GTK_NOTEBOOK (window->priv->notebook)) == 1;
+  
   group = NULL;
   i = 0;
   while (TRUE) /* should probably make us somewhat nervous */
@@ -2063,7 +2056,7 @@ reset_tab_menuitems (TerminalWindow *window)
                                                       terminal_screen_get_title (screen));
       group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menu_item));
       
-      if (i < N_TABS_WITH_ACCEL)
+      if (i < N_TABS_WITH_ACCEL && !single_page)
         accel_path = g_strdup_printf (FORMAT_ACCEL_PATH_SWITCH_TO_TAB,
                                       i + 1);
       else
@@ -2184,13 +2177,15 @@ new_window_callback (GtkWidget      *menuitem,
   if (!terminal_profile_get_forgotten (profile))
     {
       char *name;
+      const char *dir;
       
       name = gdk_screen_make_display_name (gtk_widget_get_screen (menuitem));
+      dir = terminal_screen_get_working_dir (window->priv->active_term);
 
       terminal_app_new_terminal (terminal_app_get (),
                                  profile,
                                  NULL,
-                                 FALSE, FALSE, NULL, NULL, NULL, NULL, NULL, 1.0,
+                                 FALSE, FALSE, NULL, NULL, NULL, dir, NULL, 1.0,
                                  NULL, name, -1);
 
       g_free (name);
@@ -2210,10 +2205,14 @@ new_tab_callback (GtkWidget      *menuitem,
 
   if (!terminal_profile_get_forgotten (profile))
     {
+      const char *dir;
+
+      dir = terminal_screen_get_working_dir (window->priv->active_term);
+
       terminal_app_new_terminal (terminal_app_get (),
                                  profile,
                                  window,
-                                 FALSE, FALSE, NULL, NULL, NULL, NULL, NULL, 1.0,
+                                 FALSE, FALSE, NULL, NULL, NULL, dir, NULL, 1.0,
                                  NULL, NULL, -1);
     }
 }
@@ -2512,8 +2511,6 @@ change_encoding_callback (GtkWidget      *menu_item,
 
   widget = terminal_screen_get_widget (window->priv->active_term);
   terminal_widget_set_encoding (widget, charset);
-
-  update_active_encoding_name (window);
 }
 
 static void
